

# e-Yantra Autoeval

## Usage

- For `Sentinel Drone` theme

```sh
eyantra-autoeval evaluate --year 2022 --theme SD --task 0
```

- For `Luminosity Drone` theme

```sh
eyantra-autoeval evaluate --year 2023 --theme LD --task 0
```

